@@ -25,6 +25,3 @@ chtype ncdu_acs_urcorner() { return ACS_URCORNER; }
 chtype ncdu_acs_lrcorner() { return ACS_LRCORNER; }
 chtype ncdu_acs_hline()    { return ACS_VLINE   ; }
 chtype ncdu_acs_vline()    { return ACS_HLINE   ; }
-
-/* https://github.com/ziglang/zig/issues/8947 */
-void ncdu_init_pair(int a, int b, int c) { init_pair(a,b,c); }
